@@ -82,11 +82,9 @@ class GANAdaptiveInstanceNorm(nn.Module):
         # batch_norm_output = batch_norm(
         #     x, batch_mean, batch_variance, weight=x_net_gamma, bias=x_net_beta, momentum=self.momentum, eps=self.epsilon)
 
-        # using formula to avoid handling pytorchs running_variance+running_mean of batch_norm()
-        batch_norm_output = (x_net_gamma*(x-batch_mean) /
-                             batch_variance)+x_net_beta
-
-        return batch_norm_output
+        # return batch_norm_output: using formula to avoid handling pytorchs running_variance+running_mean of batch_norm()
+        return (x_net_gamma*(x-batch_mean) /
+                batch_variance)+x_net_beta
 
     def init_weights(self):
         for module in self.modules():
@@ -145,4 +143,3 @@ class GANAdaptiveInstanceNorm2d(GANAdaptiveInstanceNorm):
         """
         super(GANAdaptiveInstanceNorm2d, self).__init__(
             num_feat_channels=channels, c=c, spectral=spectral, n_power_iterations=n_power_iterations, eps=eps, gain=gain)
-
